Module analyzing

Semantic analysis of the Tx3 language.

This module takes an AST and performs semantic analysis on it. It checks for duplicate definitions, unknown symbols, and other semantic errors.

Structs

AnalyzeReport
InvalidSymbolError
NotInScopeError

Enums

Error

Traits

Analyzable
A trait for types that can be semantically analyzed.

Functions

analyze
Performs semantic analysis on a Tx3 program AST.