pub enum BuiltInOp {
NoOp(Expression),
Add(Expression, Expression),
Sub(Expression, Expression),
Concat(Expression, Expression),
Negate(Expression),
Property(Expression, PropertyIndex),
}Expand description
Operations that are executed during the “apply” phase.
These are operations that are executed during the “apply” phase, as opposed to the compiler operations that are executed during the “compile” phase.
These ops can be executed (aka “reduced”) very early in the process. As long as they underlying expressions are “constant” (aka: don’t rely on external data), the will be simplified directly during the “apply” phase.
Variants
NoOp(Expression)
Add(Expression, Expression)
Sub(Expression, Expression)
Concat(Expression, Expression)
Negate(Expression)
Property(Expression, PropertyIndex)