pub enum CompilerOp {
BuildScriptAddress(Expression),
ComputeMinUtxo(Expression),
}Expand description
Operations that are performed by the compiler.
These are operations that are performed by the compiler, as opposed to the built-in operations that are executed (aka “reduced”) during the “apply” phase.
These ops can’t be executed earlier because they are either: chain-specific or rely on data that is only available to the compiler.
Variants
BuildScriptAddress(Expression)
ComputeMinUtxo(Expression)