pub struct AdHocDirective {
pub name: String,
pub data: HashMap<String, Expression>,
}Expand description
An ad-hoc compile directive.
It’s a generic, pass-through structure that the final chain-specific compiler can use to compile custom structures. Tx3 won’t attempt to process this IR structure for anything other than trying to apply / reduce its expressions.
Fields
name: Stringdata: HashMap<String, Expression>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for AdHocDirective
impl<'__de, __Context> BorrowDecode<'__de, __Context> for AdHocDirective
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for AdHocDirective
impl Clone for AdHocDirective
Sourcefn clone(&self) -> AdHocDirective
fn clone(&self) -> AdHocDirective
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Composite for AdHocDirective
impl Composite for AdHocDirective
fn components(&self) -> Vec<&Expression>
fn try_map_components<F>(self, f: F) -> Result<Self, Error>
fn reduce_self(self) -> Result<Self, Error>
fn reduce_nested(self) -> Result<Self, Error>
Sourceimpl Debug for AdHocDirective
impl Debug for AdHocDirective
Sourceimpl<__Context> Decode<__Context> for AdHocDirective
impl<__Context> Decode<__Context> for AdHocDirective
Sourceimpl<'de> Deserialize<'de> for AdHocDirective
impl<'de> Deserialize<'de> for AdHocDirective
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for AdHocDirective
impl Encode for AdHocDirective
Sourceimpl Node for AdHocDirective
impl Node for AdHocDirective
Sourceimpl PartialEq for AdHocDirective
impl PartialEq for AdHocDirective
Sourceimpl Serialize for AdHocDirective
impl Serialize for AdHocDirective
impl Eq for AdHocDirective
impl StructuralPartialEq for AdHocDirective